@@ -59,6 +59,9 @@ from .state_dependent_exemptions import (
 from .ctc import (
     create_ctc_older_child_supplement_reform,
     create_ctc_additional_bracket_reform,
+    create_ctc_per_child_phase_in_reform,
+    create_ctc_per_child_phase_out_reform,
+    create_ctc_minimum_refundable_amount_reform,
 )
 from .snap import (
     create_abolish_snap_deductions_reform,
@@ -105,6 +108,11 @@ from .crfb import (
     create_non_refundable_ss_credit_reform,
     create_senior_deduction_extension_reform,
 )
+from .aca import (
+    create_aca_ptc_additional_bracket_reform,
+    create_aca_ptc_simplified_bracket_reform,
+)
+
 
 from policyengine_core.reforms import Reform
 import warnings
@@ -235,6 +243,21 @@ def create_structural_reforms_from_parameters(parameters, period):
     american_worker_rebate_act = create_american_worker_rebate_act_reform(
         parameters, period
     )
+    ctc_per_child_phase_out = create_ctc_per_child_phase_out_reform(
+        parameters, period
+    )
+    ctc_per_child_phase_in = create_ctc_per_child_phase_in_reform(
+        parameters, period
+    )
+    ctc_minimum_refundable_amount = (
+        create_ctc_minimum_refundable_amount_reform(parameters, period)
+    )
+    aca_ptc_additional_bracket = create_aca_ptc_additional_bracket_reform(
+        parameters, period
+    )
+    aca_ptc_simplified_bracket = create_aca_ptc_simplified_bracket_reform(
+        parameters, period
+    )
 
     reforms = [
         afa_reform,
@@ -282,6 +305,11 @@ def create_structural_reforms_from_parameters(parameters, period):
         mi_surtax,
         additional_tax_bracket,
         american_worker_rebate_act,
+        ctc_per_child_phase_out,
+        ctc_per_child_phase_in,
+        ctc_minimum_refundable_amount,
+        aca_ptc_additional_bracket,
+        aca_ptc_simplified_bracket,
     ]
     reforms = tuple(filter(lambda x: x is not None, reforms))
 
